@@ -15,6 +15,7 @@ public:
         Stderr = 0x02,
         LogFile = 0x08,
         String = 0x10,
+        Stdout = 0x20,
         Default = Notification | LogFile | Stderr,
     };
 
@@ -43,7 +44,7 @@ public:
     AbstractLogger& enableMessageHeader(bool enable);
 
 private:
-    QString messageHeader(Channel type, Target channel);
+    QString messageHeader(Channel channel, Target target);
 
     int m_targets;
     Channel m_defaultChannel;
