@@ -3,9 +3,9 @@
 
 #pragma once
 
-#include <QWidget>
+#include "src/widgets/colorpickerwidget.h"
 
-class ColorPicker : public QWidget
+class ColorPicker : public ColorPickerWidget
 {
     Q_OBJECT
 public:
@@ -15,17 +15,7 @@ signals:
     void colorSelected(QColor c);
 
 protected:
-    void paintEvent(QPaintEvent* event) override;
-    void repaint(int i, QPainter& painter);
-    void mouseMoveEvent(QMouseEvent*) override;
     void showEvent(QShowEvent* event) override;
     void hideEvent(QHideEvent* event) override;
-
-private:
-    int m_colorAreaSize;
-    int m_selectedIndex, m_lastIndex;
-    QVector<QRect> m_colorAreaList;
-    QVector<QColor> m_colorList;
-
-    QColor m_uiColor;
+    void mouseMoveEvent(QMouseEvent* e) override;
 };
