@@ -27,13 +27,13 @@ public:
     explicit SidePanelWidget(QPixmap* p, QWidget* parent = nullptr);
 
 signals:
-    void colorChanged(const QColor& c);
-    void toolSizeChanged(int t);
+    void colorChanged(const QColor& color);
+    void toolSizeChanged(int size);
     void togglePanel();
 
 public slots:
-    void onToolSizeChanged(const int& t);
-    void onColorChanged(const QColor& c);
+    void onToolSizeChanged(int tool);
+    void onColorChanged(const QColor& color);
 
 private slots:
     void startColorGrab();
@@ -43,14 +43,14 @@ private slots:
 
 private:
     void finalizeGrab();
-    void updateColorNoWheel(const QColor& c);
+    void updateColorNoWheel(const QColor& color);
 
     bool eventFilter(QObject* obj, QEvent* event) override;
     void hideEvent(QHideEvent* event) override;
 
     QVBoxLayout* m_layout;
     QPushButton* m_colorGrabButton;
-    ColorGrabWidget* m_colorGrabber;
+    ColorGrabWidget* m_colorGrabber{};
     color_widgets::ColorWheel* m_colorWheel;
     QLabel* m_colorLabel;
     QLineEdit* m_colorHex;
@@ -58,5 +58,5 @@ private:
     QColor m_color;
     QColor m_revertColor;
     QSlider* m_toolSizeSlider;
-    int m_toolSize;
+    int m_toolSize{};
 };
